ReceiverBandwidth

Enum ReceiverBandwidth 

#[non_exhaustive]
pub enum ReceiverBandwidth { MetadataOnly, AudioOnly, Lowest, Highest, }
Operational bandwidth modes for receivers.

These values are receiver configuration modes that the NDI SDK can use for normal receive operation. SDK Max sentinel values are intentionally not exposed in safe Rust because they are placeholders, not valid receiver modes.

This enum is marked #[non_exhaustive] so future SDK receiver modes can be added without another avoidable public enum break. Downstream match expressions should include a wildcard arm.

Choose an explicit operational value such as ReceiverBandwidth::Highest, ReceiverBandwidth::Lowest, ReceiverBandwidth::AudioOnly, or ReceiverBandwidth::MetadataOnly for receiver configuration.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


MetadataOnly



AudioOnly



Lowest



Highest